#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class SearchSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         SearchSettingAtt
                | 
                | Represents the setting controller for the Search property tab
                | page.
                | Role: The setting controller is the object that enables to get and set setting
                | parameters.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.search_setting_att = com_object

    @property
    def deep_search_activation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DeepSearchActivation() As boolean
                | 
                |     Returns or sets the Deep Search Activation attribute.
                |     Role: The Deep Search Activation attribute manages the Deep Search option
                |     available in the Search dialog box used to determine whether documents in
                |     visualization mode must be transiently loaded during a search query

        :return: bool
        :rtype: bool
        """

        return self.search_setting_att.DeepSearchActivation

    @deep_search_activation.setter
    def deep_search_activation(self, value: bool):
        """
        :param bool value:
        """

        self.search_setting_att.DeepSearchActivation = value

    @property
    def default_power_input_context_priority(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DefaultPowerInputContextPriority() As boolean
                | 
                |     Returns or sets the Default Power Input Context Priority
                |     attribute.
                |     Role: The Default Power Input Context Priority attribute manages whether
                |     the default context scope must override the context scope stored in a favorite
                |     query

        :return: bool
        :rtype: bool
        """

        return self.search_setting_att.DefaultPowerInputContextPriority

    @default_power_input_context_priority.setter
    def default_power_input_context_priority(self, value: bool):
        """
        :param bool value:
        """

        self.search_setting_att.DefaultPowerInputContextPriority = value

    @property
    def default_power_input_context_scope(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DefaultPowerInputContextScope() As
                | CATSearchContextScope
                | 
                |     Returns or sets the Default Power Input Context Scope
                |     attribute.
                |     Role: The Default Power Input Context Scope attribute manages the default
                |     context scope to be used when none is typed in the Power Input field

        :return: int
        :rtype: int
        """

        return self.search_setting_att.DefaultPowerInputContextScope

    @default_power_input_context_scope.setter
    def default_power_input_context_scope(self, value: int):
        """
        :param int value:
        """

        self.search_setting_att.DefaultPowerInputContextScope = value

    @property
    def default_power_input_prefix(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DefaultPowerInputPrefix() As CATBSTR
                | 
                |     Returns or sets the Default Power Input Prefix attribute.
                |     Role: The Default Power Input Prefix attribute manages the default prefix
                |     to be used when none is typed in the Power Input field

        :return: str
        :rtype: str
        """

        return self.search_setting_att.DefaultPowerInputPrefix

    @default_power_input_prefix.setter
    def default_power_input_prefix(self, value: str):
        """
        :param str value:
        """

        self.search_setting_att.DefaultPowerInputPrefix = value

    @property
    def max_displayed_results(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaxDisplayedResults() As long
                | 
                |     Returns or sets the Max Displayed Results attribute.
                |     Role: The Max Displayed Results attribute indicates the maximum number of
                |     elements that can be displayed in the Search results page. Displaying too many
                |     lines can stick more or less the results list so it is recommended to limit
                |     this number.

        :return: int
        :rtype: int
        """

        return self.search_setting_att.MaxDisplayedResults

    @max_displayed_results.setter
    def max_displayed_results(self, value: int):
        """
        :param int value:
        """

        self.search_setting_att.MaxDisplayedResults = value

    @property
    def max_pre_highlighted_elements(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property MaxPreHighlightedElements() As long
                | 
                |     Returns or sets the Max Pre-Highlighted Elements
                |     attribute.
                |     Role: The Max Pre-Highlighted Elements attribute indicates the maximum
                |     number of elements that can be displayed in the Search results page. Displaying
                |     too many elements can stick the session so it is strongly recommended to limit
                |     this number.

        :return: int
        :rtype: int
        """

        return self.search_setting_att.MaxPreHighlightedElements

    @max_pre_highlighted_elements.setter
    def max_pre_highlighted_elements(self, value: int):
        """
        :param int value:
        """

        self.search_setting_att.MaxPreHighlightedElements = value

    def get_deep_search_activation_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDeepSearchActivationInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Deep Search Activation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.search_setting_att.GetDeepSearchActivationInfo(o_admin_level, o_locked)

    def get_default_power_input_context_priority_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDefaultPowerInputContextPriorityInfo(CATBSTR
                | oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Default Power Input Context Priority
                |     setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.search_setting_att.GetDefaultPowerInputContextPriorityInfo(o_admin_level, o_locked)

    def get_default_power_input_context_scope_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDefaultPowerInputContextScopeInfo(CATBSTR
                | oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Default Power Input Context Scope setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.search_setting_att.GetDefaultPowerInputContextScopeInfo(o_admin_level, o_locked)

    def get_default_power_input_prefix_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDefaultPowerInputPrefixInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Default Power Input Prefix setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.search_setting_att.GetDefaultPowerInputPrefixInfo(o_admin_level, o_locked)

    def get_max_displayed_results_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMaxDisplayedResultsInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Max Displayed Results setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.search_setting_att.GetMaxDisplayedResultsInfo(o_admin_level, o_locked)

    def get_max_pre_highlighted_elements_info(self, o_admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetMaxPreHighlightedElementsInfo(CATBSTR oAdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the Max Displayed Results setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str o_admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.search_setting_att.GetMaxPreHighlightedElementsInfo(o_admin_level, o_locked)

    def set_deep_search_activation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDeepSearchActivationLock(boolean iLocked)
                | 
                |     Locks or unlocks the Deep Search Activation setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.search_setting_att.SetDeepSearchActivationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_deep_search_activation_lock'
        # # vba_code = """
        # # Public Function set_deep_search_activation_lock(search_setting_att)
        # #     Dim iLocked (2)
        # #     search_setting_att.SetDeepSearchActivationLock iLocked
        # #     set_deep_search_activation_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_power_input_context_priority_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDefaultPowerInputContextPriorityLock(boolean
                | iLocked)
                | 
                |     Locks or unlocks the Default Power Input Context Priority setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.search_setting_att.SetDefaultPowerInputContextPriorityLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_power_input_context_priority_lock'
        # # vba_code = """
        # # Public Function set_default_power_input_context_priority_lock(search_setting_att)
        # #     Dim iLocked (2)
        # #     search_setting_att.SetDefaultPowerInputContextPriorityLock iLocked
        # #     set_default_power_input_context_priority_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_power_input_context_scope_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDefaultPowerInputContextScopeLock(boolean iLocked)
                | 
                |     Locks or unlocks the Default Power Input Context Scope setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.search_setting_att.SetDefaultPowerInputContextScopeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_power_input_context_scope_lock'
        # # vba_code = """
        # # Public Function set_default_power_input_context_scope_lock(search_setting_att)
        # #     Dim iLocked (2)
        # #     search_setting_att.SetDefaultPowerInputContextScopeLock iLocked
        # #     set_default_power_input_context_scope_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_power_input_prefix_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDefaultPowerInputPrefixLock(boolean iLocked)
                | 
                |     Locks or unlocks the Default Power Input Prefix setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.search_setting_att.SetDefaultPowerInputPrefixLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_power_input_prefix_lock'
        # # vba_code = """
        # # Public Function set_default_power_input_prefix_lock(search_setting_att)
        # #     Dim iLocked (2)
        # #     search_setting_att.SetDefaultPowerInputPrefixLock iLocked
        # #     set_default_power_input_prefix_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_max_displayed_results_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMaxDisplayedResultsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Max Displayed Results setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.search_setting_att.SetMaxDisplayedResultsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_max_displayed_results_lock'
        # # vba_code = """
        # # Public Function set_max_displayed_results_lock(search_setting_att)
        # #     Dim iLocked (2)
        # #     search_setting_att.SetMaxDisplayedResultsLock iLocked
        # #     set_max_displayed_results_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_max_pre_highlighted_elements_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetMaxPreHighlightedElementsLock(boolean iLocked)
                | 
                |     Locks or unlocks the Max Displayed Results setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.search_setting_att.SetMaxPreHighlightedElementsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_max_pre_highlighted_elements_lock'
        # # vba_code = """
        # # Public Function set_max_pre_highlighted_elements_lock(search_setting_att)
        # #     Dim iLocked (2)
        # #     search_setting_att.SetMaxPreHighlightedElementsLock iLocked
        # #     set_max_pre_highlighted_elements_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SearchSettingAtt(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape
from pycatia.mec_mod_interfaces.shape import Shape


class Rotate(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         Rotate
                | 
                | Represents the shape rotate feature object.
                | This solid feature is created from an underlying HybridShapeRotate aggregated
                | by the Rotate. Role: To access the data of the hybrid shape rotate feature
                | object. This data includes:
                | 
                |     The element to be rotated
                |     The rotation axis
                |     The angle and its value
                | 
                | Use the CATIAShapeFactory to create ShapeFeature object.
                | 
                | See also:
                |     ShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rotate = com_object

    @property
    def angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Angle() As Angle (Read Only)
                | 
                |     Returns the rotation angle.

        :return: Angle
        :rtype: Angle
        """

        return Angle(self.rotate.Angle)

    @property
    def angle_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property AngleValue() As double
                | 
                |     Returns or sets the rotation angle value.
                | 
                |     Example: This example retrieves in AngleValue the angle value for the
                |     Rotate hybrid shape feature.
                | 
                |      Dim AngleValue As double
                |      Set AngleValue = Rotate.AngleValue

        :return: float
        :rtype: float
        """

        return self.rotate.AngleValue

    @angle_value.setter
    def angle_value(self, value: float):
        """
        :param float value:
        """

        self.rotate.AngleValue = value

    @property
    def axis(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Axis() As Reference
                | 
                |     Returns or sets the rotation axis.
                |     To set the property, you can use one of the following Boundary objects:
                |     RectilinearTriDimFeatEdge, RectilinearBiDimFeatEdge or
                |     RectilinearMonoDimFeatEdge.
                | 
                |     Example: This example retrieves in RotationAxis the rotation axis for the
                |     Rotate hybrid shape feature.
                | 
                |      Dim RotationAxis As Reference
                |      Set RotationAxis = Rotate.Axis

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.rotate.Axis)

    @axis.setter
    def axis(self, value: Reference):
        """
        :param Reference value:
        """

        self.rotate.Axis = value

    @property
    def hybrid_shape(self) -> HybridShape:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property HybridShape() As HybridShape (Read Only)
                | 
                |     Gets the underlying HybridShapeRotate.
                | 
                |     Example:
                |         The following example explains how to retrieve the underlying
                |         HybridShape Rotate
                | 
                |           Dim oHybridShape as AnyObject
                |           Set oHybridShape=oRotate.HybridShape
                |           oHybridShape.SectionCoupling = 2

        :return: HybridShape
        :rtype: HybridShape
        """

        return HybridShape(self.rotate.HybridShape)

    def __repr__(self):
        return f'Rotate(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.space_analyses_interfaces.clash import Clash
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Clashes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Clashes
                | 
                | A collection of all Clash objects currently managed by the
                | application.
                | 
                | The method GetTechnologicalObject("Clashes") on the root product, allows you to
                | retrieve this collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.clashes = com_object

    def add(self) -> Clash:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add() As Clash
                | 
                |     Creates a Clash object which takes all products into account and adds it to
                |     the Clashes collection.
                | 
                |     Returns:
                |         The created Clash 
                |     Example:
                | 
                |              This example creates a new Clash in the TheClashes
                |              collection.
                |             
                | 
                |             Dim NewClash As Clash
                |             Set NewClash = TheClashes.Add

        :return: Clash
        :rtype: Clash
        """
        return Clash(self.clashes.Add())

    def add_from_sel(self) -> Clash:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func AddFromSel() As Clash
                | 
                |     Creates a Clash object which takes all products in the selection into
                |     account and adds it to the Clashes collection.
                | 
                |     Returns:
                |         The created Clash 
                |     Example:
                | 
                |              This example creates a new Clash in the TheClashes
                |              collection.
                |             
                | 
                |             Dim NewClash As Clash
                |             Set NewClash = TheClashes.AddFromSel

        :return: Clash
        :rtype: Clash
        """
        return Clash(self.clashes.AddFromSel())

    def item(self, i_index: cat_variant) -> Clash:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As Clash
                | 
                |     Returns a Clash object using its index or its name from the Clashes
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Clash to retrieve from the collection
                |             of Clashes. As a numerics, this index is the rank of the Clash in the
                |             collection. The index of the first Clash in the collection is 1, and the index
                |             of the last Clash is Count. As a string, it is the name you assigned to the
                |             Clash. 
                | 
                |     Example:
                | 
                |              This example retrieves in ThisClash the ninth
                |              Clash,
                |             and in ThatClash the Clash named
                |             Clash Of MyProduct from the TheClashes collection.
                |             
                |             
                | 
                |             Dim ThisClash As Clash
                |             Set ThisClash = TheClashes.Item(9)
                |             Dim ThatClash As Clash
                |             Set ThatClash = TheClashes.Item("Clash Of MyProduct")

        :param cat_variant i_index:
        :return: Clash
        :rtype: Clash
        """
        return Clash(self.clashes.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes a Clash object from the Clashes collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Clash to remove from the collection of
                |             Clashes. As a numerics, this index is the rank of the Clash in the collection.
                |             The index of the first Clash in the collection is 1, and the index of the last
                |             Clash is Count. As a string, it is the name you assigned to the Clash.
                |             
                | 
                |     Example:
                | 
                |              The following example removes the tenth Clash and the Clash
                |              named
                |             Clash Of MyProduct from the TheClashes collection.
                |             
                | 
                |             TheClashes.Remove(10)
                |             TheClashes.Remove("Clash Of MyProduct")

        :param cat_variant i_index:
        :return: None
        :rtype: None
        """
        return self.clashes.Remove(i_index)

    def __getitem__(self, n: int) -> Clash:
        if (n + 1) > self.count:
            raise StopIteration

        return Clash(self.clashes.item(n + 1))

    def __iter__(self) -> Iterator[Clash]:
        for i in range(self.count):
            yield self.child_object(self.com_object.item(i + 1))

    def __repr__(self):
        return f'Clashes(name="{self.name}")'



#! /usr/bin/python3.6

import setuptools

from pycatia import __author__, __author_email, __description__, __name__, __version__, __url__

exclude_files = [
    '__reference_scripts__',
    '__pycache__',
]

requires = [
    'pywin32>=224',
]

test_requirements = [
    'pytest>=5.4.2',
    'pytest-cov>=2.8.1',
]

with open("README.rst", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name=__name__,
    version=__version__,
    author=__author__,
    author_email=__author_email,
    description=__description__,
    long_description=long_description,
    long_description_content_type="text/x-rst",
    url=__url__,
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
    classifiers=[
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        "License :: OSI Approved :: MIT License",
        "Operating System :: Microsoft :: Windows",
    ],
    tests_require=test_requirements,
    install_requires=requires,
)



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.navigator_interfaces.dmu_reviews import DMUReviews


class DMUReview(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMUReview
                | 
                | Represents a DMU Review.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dmu_review = com_object

    @property
    def activation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Activation() As long
                | 
                |     Returns or sets the activation.
                | 
                |     Returns:
                |         The activation
                | 
                |             0: the DMU Review is inactivated.
                |             1: the DMU Review is activated. 
                | 
                |     Example:
                | 
                |              This example retrieves the activation of the oDMUReview DMU Review
                |              and activates it.
                |             
                | 
                |             Activation = oDMUReview.Activation
                |             oDMUReview.Activation = 1

        :return: int
        :rtype: int
        """

        return self.dmu_review.Activation

    @activation.setter
    def activation(self, value: int):
        """
        :param int value:
        """

        self.dmu_review.Activation = value

    @property
    def dmu_reviews(self) -> 'DMUReviews':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DMUReviews() As DMUReviews (Read Only)
                | 
                |     Returns the DMUReviews Collection associated with the DMUReview
                |     (children).
                | 
                |     Example:
                | 
                |              This example retrieves the cDMUReviews collection
                |             from the oDMUReview DMU Review.
                |             
                | 
                |             Set cDMUReviews = oDMUReview.DMUReviews(9)

        :return: DMUReviews
        :rtype: DMUReviews
        """
        from pycatia.navigator_interfaces.dmu_reviews import DMUReviews
        return DMUReviews(self.dmu_review.DMUReviews)

    def __repr__(self):
        return f'DmuReview(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.line import Line
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class HybridShapeLineBisecting(Line):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.Line
                |                             HybridShapeLineBisecting
                | 
                | Represents the hybrid shape bisecting line feature object.
                | Role: To access the data of the hybrid shape bisecting line feature object.
                | This data includes:
                | 
                |     The two lines used to create the bisecting line
                |     The reference point
                |     The support
                |     The start and end offsets
                |     The orientation
                |     The solution type
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeAffinity
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_line_bisecting = com_object

    @property
    def begin_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BeginOffset() As Length (Read Only)
                | 
                |     Returns the start offset of the line.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_line_bisecting.BeginOffset)

    @property
    def elem1(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Elem1() As Reference
                | 
                |     Returns or sets the first line used to create the bisecting
                |     line.
                | 
                |     Sub-element(s) supported (see Boundary object): see
                |     RectilinearTriDimFeatEdge or RectilinearBiDimFeatEdge.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_bisecting.Elem1)

    @elem1.setter
    def elem1(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_line_bisecting.Elem1 = reference_element

    @property
    def elem2(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Elem2() As Reference
                | 
                |     Returns or sets the second line used to create the bisecting
                |     line.
                |     Sub-element(s) supported (see Boundary object): see
                |     RectilinearTriDimFeatEdge or RectilinearBiDimFeatEdge.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_bisecting.Elem2)

    @elem2.setter
    def elem2(self, reference_element: Reference):
        """
        :param Reference reference_element:
        """

        self.hybrid_shape_line_bisecting.Elem2 = reference_element.com_object

    @property
    def end_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property EndOffset() As Length (Read Only)
                | 
                |     Returns the end offset of the line.

        :return: Length
        :rtype: Length
        """

        return Length(self.hybrid_shape_line_bisecting.EndOffset)

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Returns or sets the orientation used to compute the bisecting
                |     line.
                |     Role: the orientation specifies bisecting line position
                |     Legal values: The orientation can be the same(1) or the inverse(-1)

        :return: int
        :rtype: int
        """

        return self.hybrid_shape_line_bisecting.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_line_bisecting.Orientation = value

    @property
    def ref_point(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RefPoint() As Reference
                | 
                |     Returns or sets the reference point used to create the bisecting
                |     line.
                |     Sub-element(s) supported (see Boundary object): see Vertex.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_bisecting.RefPoint)

    @ref_point.setter
    def ref_point(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_line_bisecting.RefPoint = reference_point.com_object

    @property
    def solution_type(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SolutionType() As boolean
                | 
                |     Returns or sets the solution type.
                |     Role: The solution type allows you to know where is the bisecting line.

        :return: bool
        :rtype: bool
        """

        return self.hybrid_shape_line_bisecting.SolutionType

    @solution_type.setter
    def solution_type(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_line_bisecting.SolutionType = value

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the support used to create the bisecting
                |     line.
                | 
                |     Parameters:
                | 
                |         oElem
                |             retrieve the support of the bisecting line.
                |             Sub-element(s) supported (see 
                | 
                |         Boundary object): see Face.

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.hybrid_shape_line_bisecting.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_line_bisecting.Support = reference_support.com_object

    def get_length_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLengthType() As long
                | 
                |     Gets the length type Default is 0.
                | 
                |     Parameters:
                | 
                |         oType
                |             The length type = 0 : length - the line is limited by its extremities =
                |             1 : infinite - the line is infinite = 2 : infinite start point - the line is infinite on
                |             the side of the start point = 3 : infinite end point - the line is infinite on the side
                |              of the end point

        :return: int
        :rtype: int
        """
        return self.hybrid_shape_line_bisecting.GetLengthType()

    def get_symmetrical_extension(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetSymmetricalExtension() As boolean
                | 
                |     Gets whether the symmetrical extension of the line is
                |     active.
                | 
                |     Parameters:
                | 
                |         oSym
                |             Symetry flag

        :return: bool
        :rtype: bool
        """
        return self.hybrid_shape_line_bisecting.GetSymmetricalExtension()

    def set_length_type(self, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLengthType(long iType)
                | 
                |     Sets the length type Default is 0.
                | 
                |     Parameters:
                | 
                |         iType
                |             The length type = 0 : length - the line is limited by its extremities =
                |             1 : infinite - the line is infinite = 2 : infinite start point - the line is infinite on
                |             the side of the start point = 3 : infinite end point - the line is infinite on the side
                |             of the end point

        :param int i_type:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_line_bisecting.SetLengthType(i_type)

    def set_symmetrical_extension(self, i_sym: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetSymmetricalExtension(boolean iSym)
                | 
                |     Sets the symmetrical extension of the line (start = -end).
                | 
                |     Parameters:
                | 
                |         iSym
                |             Symetry flag

        :param bool i_sym:
        :return: None
        :rtype: None
        """
        return self.hybrid_shape_line_bisecting.SetSymmetricalExtension(i_sym)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_symmetrical_extension'
        # # vba_code = """
        # # Public Function set_symmetrical_extension(hybrid_shape_line_bisecting)
        # #     Dim iSym (2)
        # #     hybrid_shape_line_bisecting.SetSymmetricalExtension iSym
        # #     set_symmetrical_extension = iSym
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HybridShapeLineBisecting(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class DraftingSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         DraftingSettingAtt
                | 
                | Manages drafting settings.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.drafting_setting_att = com_object

    @property
    def create_new_sheet_from(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property CreateNewSheetFrom() As CatDrwNewSheetFrom
                | 
                |     Returns the CreateNewSheetFrom parameter.

        :return: int
        :rtype: int
        """

        return self.drafting_setting_att.CreateNewSheetFrom

    @create_new_sheet_from.setter
    def create_new_sheet_from(self, value: int):
        """
        :param int value:
        """

        self.drafting_setting_att.CreateNewSheetFrom = value

    @property
    def display_reset_button(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DisplayResetButton() As boolean
                | 
                |     Returns the DisplayResetButton parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.DisplayResetButton

    @display_reset_button.setter
    def display_reset_button(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.DisplayResetButton = value

    @property
    def lock_user_default(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property LockUserDefault() As boolean
                | 
                |     Returns the LockUserDefault parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.LockUserDefault

    @lock_user_default.setter
    def lock_user_default(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.LockUserDefault = value

    @property
    def prevent_background_access(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventBackgroundAccess() As boolean
                | 
                |     Returns the PreventBackgroundAccess parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.PreventBackgroundAccess

    @prevent_background_access.setter
    def prevent_background_access(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventBackgroundAccess = value

    @property
    def prevent_dim_driving_3d_cstr(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventDimDriving3DCstr() As boolean
                | 
                |     Returns the PreventDimDriving3DCstr parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.PreventDimDriving3DCstr

    @prevent_dim_driving_3d_cstr.setter
    def prevent_dim_driving_3d_cstr(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventDimDriving3DCstr = value

    @property
    def prevent_file_new(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventFileNew() As boolean
                | 
                |     Returns the PreventFileNew parameter.

        :return: bool
        """

        return self.drafting_setting_att.PreventFileNew

    @prevent_file_new.setter
    def prevent_file_new(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventFileNew = value

    @property
    def prevent_gen_view_style(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventGenViewStyle() As boolean
                | 
                |     Returns the PreventGenViewStyle parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.PreventGenViewStyle

    @prevent_gen_view_style.setter
    def prevent_gen_view_style(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventGenViewStyle = value

    @property
    def prevent_set_as_default(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventSetAsDefault() As boolean
                | 
                |     Returns the PreventSetAsDefault parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.PreventSetAsDefault

    @prevent_set_as_default.setter
    def prevent_set_as_default(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventSetAsDefault = value

    @property
    def prevent_switch_standard(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventSwitchStandard() As boolean
                | 
                |     Returns the PreventSwitchStandard parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.PreventSwitchStandard

    @prevent_switch_standard.setter
    def prevent_switch_standard(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventSwitchStandard = value

    @property
    def prevent_true_dimension_creation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventTrueDimensionCreation() As boolean
                | 
                |     Returns the PreventTrueDimensionCreation parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.PreventTrueDimensionCreation

    @prevent_true_dimension_creation.setter
    def prevent_true_dimension_creation(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventTrueDimensionCreation = value

    @property
    def prevent_update_standard(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventUpdateStandard() As boolean
                | 
                |     Returns the PreventUpdateStandard parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.PreventUpdateStandard

    @prevent_update_standard.setter
    def prevent_update_standard(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventUpdateStandard = value

    @property
    def prevent_view_geom_upgrade(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property PreventViewGeomUpgrade() As boolean
                | 
                |     Returns the PreventViewGeomUpgrade parameter.

        :return: bool
        """

        return self.drafting_setting_att.PreventViewGeomUpgrade

    @prevent_view_geom_upgrade.setter
    def prevent_view_geom_upgrade(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.PreventViewGeomUpgrade = value

    @property
    def use_style_create_objects(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property UseStyleCreateObjects() As boolean
                | 
                |     Returns the UseStyleCreateObjects parameter.

        :return: bool
        :rtype: bool
        """

        return self.drafting_setting_att.UseStyleCreateObjects

    @use_style_create_objects.setter
    def use_style_create_objects(self, value: bool):
        """
        :param bool value:
        """

        self.drafting_setting_att.UseStyleCreateObjects = value

    def get_create_new_sheet_from_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetCreateNewSheetFromInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the CreateNewSheetFrom
                |     parameter.
                |     Role:Retrieves the state of the CreateNewSheetFrom parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetCreateNewSheetFromInfo(io_admin_level, io_locked)

    def get_display_reset_button_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDisplayResetButtonInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DisplayResetButton
                |     parameter.
                |     Role:Retrieves the state of the DisplayResetButton parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetDisplayResetButtonInfo(io_admin_level, io_locked)

    def get_lock_user_default_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetLockUserDefaultInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LockUserDefault
                |     parameter.
                |     Role:Retrieves the state of the LockUserDefault parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetLockUserDefaultInfo(io_admin_level, io_locked)

    def get_prevent_background_access_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventBackgroundAccessInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventBackgroundAccess
                |     parameter.
                |     Role:Retrieves the state of the PreventBackgroundAccess parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventBackgroundAccessInfo(io_admin_level, io_locked)

    def get_prevent_dim_driving_3d_cstr_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventDimDriving3DCstrInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventDimDriving3DCstr
                |     parameter.
                |     Role:Retrieves the state of the PreventDimDriving3DCstr parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventDimDriving3DCstrInfo(io_admin_level, io_locked)

    def get_prevent_file_new_info(self, io_admin_level: str, io_locked: str, o_modified: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub GetPreventFileNewInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked,
                | boolean oModified)
                | 
                |     Retrieves environment informations for the PreventFileNew
                |     parameter.
                |     Role:Retrieves the state of the PreventFileNew parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :param bool o_modified:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.GetPreventFileNewInfo(io_admin_level, io_locked, o_modified)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_prevent_file_new_info'
        # # vba_code = """
        # # Public Function get_prevent_file_new_info(drafting_setting_att)
        # #     Dim ioAdminLevel (2)
        # #     drafting_setting_att.GetPreventFileNewInfo ioAdminLevel
        # #     get_prevent_file_new_info = ioAdminLevel
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_prevent_gen_view_style_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventGenViewStyleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventGenViewStyle
                |     parameter.
                |     Role:Retrieves the state of the PreventGenViewStyle parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventGenViewStyleInfo(io_admin_level, io_locked)

    def get_prevent_set_as_default_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventSetAsDefaultInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventSetAsDefault
                |     parameter.
                |     Role:Retrieves the state of the PreventSetAsDefault parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventSetAsDefaultInfo(io_admin_level, io_locked)

    def get_prevent_switch_standard_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventSwitchStandardInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventSwitchStandard
                |     parameter.
                |     Role:Retrieves the state of the PreventSwitchStandard parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventSwitchStandardInfo(io_admin_level, io_locked)

    def get_prevent_true_dimension_creation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventTrueDimensionCreationInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventTrueDimensionCreation
                |     parameter.
                |     Role:Retrieves the state of the PreventTrueDimensionCreation parameter in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventTrueDimensionCreationInfo(io_admin_level, io_locked)

    def get_prevent_update_standard_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventUpdateStandardInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventUpdateStandard
                |     parameter.
                |     Role:Retrieves the state of the PreventUpdateStandard parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventUpdateStandardInfo(io_admin_level, io_locked)

    def get_prevent_view_geom_upgrade_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetPreventViewGeomUpgradeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the PreventViewGeomUpgrade
                |     parameter.
                |     Role:Retrieves the state of the PreventViewGeomUpgrade parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetPreventViewGeomUpgradeInfo(io_admin_level, io_locked)

    def get_use_style_create_objects_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetUseStyleCreateObjectsInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UseStyleCreateObjects
                |     parameter.
                |     Role:Retrieves the state of the UseStyleCreateObjects parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :return: bool
        :rtype: bool
        """
        return self.drafting_setting_att.GetUseStyleCreateObjectsInfo(io_admin_level, io_locked)

    def set_create_new_sheet_from_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetCreateNewSheetFromLock(boolean iLocked)
                | 
                |     Locks or unlocks the CreateNewSheetFrom parameter.
                |     Role:Locks or unlocks the CreateNewSheetFrom parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetCreateNewSheetFromLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_create_new_sheet_from_lock'
        # # vba_code = """
        # # Public Function set_create_new_sheet_from_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetCreateNewSheetFromLock iLocked
        # #     set_create_new_sheet_from_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_display_reset_button_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetDisplayResetButtonLock(boolean iLocked)
                | 
                |     Locks or unlocks the DisplayResetButton parameter.
                |     Role:Locks or unlocks the DisplayResetButton parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetDisplayResetButtonLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_display_reset_button_lock'
        # # vba_code = """
        # # Public Function set_display_reset_button_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetDisplayResetButtonLock iLocked
        # #     set_display_reset_button_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_lock_user_default_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetLockUserDefaultLock(boolean iLocked)
                | 
                |     Locks or unlocks the LockUserDefault parameter.
                |     Role:Locks or unlocks the LockUserDefault parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetLockUserDefaultLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_lock_user_default_lock'
        # # vba_code = """
        # # Public Function set_lock_user_default_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetLockUserDefaultLock iLocked
        # #     set_lock_user_default_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_background_access_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventBackgroundAccessLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventBackgroundAccess parameter.
                |     Role:Locks or unlocks the PreventBackgroundAccess parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventBackgroundAccessLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_background_access_lock'
        # # vba_code = """
        # # Public Function set_prevent_background_access_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventBackgroundAccessLock iLocked
        # #     set_prevent_background_access_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_dim_driving_3d_cstr_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventDimDriving3DCstrLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventDimDriving3DCstr parameter.
                |     Role:Locks or unlocks the PreventDimDriving3DCstr parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventDimDriving3DCstrLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_dim_driving3_d_cstr_lock'
        # # vba_code = """
        # # Public Function set_prevent_dim_driving3_d_cstr_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventDimDriving3DCstrLock iLocked
        # #     set_prevent_dim_driving3_d_cstr_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_file_new_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventFileNewLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventFileNew parameter.
                |     Role:Locks or unlocks the PreventFileNew parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventFileNewLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_file_new_lock'
        # # vba_code = """
        # # Public Function set_prevent_file_new_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventFileNewLock iLocked
        # #     set_prevent_file_new_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_gen_view_style_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventGenViewStyleLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventGenViewStyle parameter.
                |     Role:Locks or unlocks the PreventGenViewStyle parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventGenViewStyleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_gen_view_style_lock'
        # # vba_code = """
        # # Public Function set_prevent_gen_view_style_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventGenViewStyleLock iLocked
        # #     set_prevent_gen_view_style_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_set_as_default_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventSetAsDefaultLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventSetAsDefault parameter.
                |     Role:Locks or unlocks the PreventSetAsDefault parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventSetAsDefaultLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_set_as_default_lock'
        # # vba_code = """
        # # Public Function set_prevent_set_as_default_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventSetAsDefaultLock iLocked
        # #     set_prevent_set_as_default_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_switch_standard_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventSwitchStandardLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventSwitchStandard parameter.
                |     Role:Locks or unlocks the PreventSwitchStandard parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventSwitchStandardLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_switch_standard_lock'
        # # vba_code = """
        # # Public Function set_prevent_switch_standard_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventSwitchStandardLock iLocked
        # #     set_prevent_switch_standard_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_true_dimension_creation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventTrueDimensionCreationLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventTrueDimensionCreation
                |     parameter.
                |     Role:Locks or unlocks the PreventTrueDimensionCreation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventTrueDimensionCreationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_true_dimension_creation_lock'
        # # vba_code = """
        # # Public Function set_prevent_true_dimension_creation_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventTrueDimensionCreationLock iLocked
        # #     set_prevent_true_dimension_creation_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_update_standard_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventUpdateStandardLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventUpdateStandard parameter.
                |     Role:Locks or unlocks the PreventUpdateStandard parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetPreventUpdateStandardLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_update_standard_lock'
        # # vba_code = """
        # # Public Function set_prevent_update_standard_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventUpdateStandardLock iLocked
        # #     set_prevent_update_standard_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_prevent_view_geom_upgrade_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetPreventViewGeomUpgradeLock(boolean iLocked)
                | 
                |     Locks or unlocks the PreventViewGeomUpgrade parameter.
                |     Role:Locks or unlocks the PreventViewGeomUpgrade parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        """
        return self.drafting_setting_att.SetPreventViewGeomUpgradeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_prevent_view_geom_upgrade_lock'
        # # vba_code = """
        # # Public Function set_prevent_view_geom_upgrade_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetPreventViewGeomUpgradeLock iLocked
        # #     set_prevent_view_geom_upgrade_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_use_style_create_objects_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetUseStyleCreateObjectsLock(boolean iLocked)
                | 
                |     Locks or unlocks the UseStyleCreateObjects parameter.
                |     Role:Locks or unlocks the UseStyleCreateObjects parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.drafting_setting_att.SetUseStyleCreateObjectsLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_use_style_create_objects_lock'
        # # vba_code = """
        # # Public Function set_use_style_create_objects_lock(drafting_setting_att)
        # #     Dim iLocked (2)
        # #     drafting_setting_att.SetUseStyleCreateObjectsLock iLocked
        # #     set_use_style_create_objects_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DraftingSettingAtt(name="{self.name}")'



#! /usr/bin/python3.6

from pycatia.in_interfaces.reference import Reference
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService


class Measurable(AnyObject):
    """
    The interface to access a CATIAMeasurable Get measurements on the object.

    .. note::
        CAA V5 Visual Basic help

        Two types of measurement can be done:

        | itself : gives dimensions related to the object itself (ex the radius of a circle).
        | between : gives dimensions related to another object (ex the distance between two products).
        | A restriction occurs for distance between: bodies (CATBody) cannot be measured.

        | Methods on VOLUME : GetVolume GetArea GetCOG
        | Methods on SURFACE : GetArea GetCOG GetPerimeter
        | Methods on PLANE : GetArea GetCOG GetPlane
        | Methods on CYLINDER : GetArea GetCOG GetAxis GetPointsOnAxis GetRadius
        | Methods on CONE : GetArea GetCOG GetAxis GetPointsOnAxis GetAngle
        | Methods on SPHERE : GetArea GetCOG GetRadius GetCenter
        | Methods on CURVE : GetLength GetCOG GetPointsOnCurve
        | Methods on LINE : GetLength GetCOG GetPointsOnCurve GetDirection
        | Methods on CIRCLE : GetLength GetCOG GetPointsOnCurve GetRadius GetCenter GetAngle GetAxis
        | Methods on POINT : GetPoint
        | Methods on AXIS SYST : GetAxisSystem

    """

    def __init__(self, com_object):
        """
        :param com_object:
        """
        super().__init__(com_object)
        self.measurable = com_object

    @property
    def angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Property Angle( ) As double (Read Only)

            | Returns the Angle of a circle or cone.
            | Example:
            | This example retrieves the Angle of NewMeasurable measure.
            |
            | Dim AAngle As double
            | AAngle = NewMeasurable.Angle


        :return: float
        :rtype: float
        """

        return self.measurable.Angle

    @property
    def area(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Property Area( ) As double (Read Only)

            | Returns the area of the surface or wet area from volume.
            | Example:
            | This example retrieves the area of NewMeasurable measure. The area unit given by oArea is m²
            |   Dim AArea As double
            |   AArea = NewMeasurable.Area


        :return: float
        :rtype: float
        """
        return self.measurable.Area

    @property
    def geometry_name(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

        :return: int
        :rtype: int
            | Returns the name of the geometry of the measured object.
            | Example:
            | This example retrieves the name of the geometry of the NewMeasurable measure.
            |   Dim AGeometryName As CatMeasurableName
            |   AGeometryName = NewMeasurable.GeometryName


        :return: int enumeration_type.measurable_name
        """

        return self.measurable.GeometryName

    @property
    def length(self) -> float:
        """
        ..note::
            CAA V5 Visual Basic help

            Property Length( ) As double (Read Only)

            | Returns the Length of a curve.
            | Example:
            | This example retrieves the Length of NewMeasurable measure.
            |   Dim ALength As double
            |   ALength = NewMeasurable.Length


        :return: float
        :rtype: float
        """

        return self.measurable.Length

    @property
    def perimeter(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Property Perimeter( ) As double (Read Only)

            | Returns the perimeter of a surface.
            | Example:
            | This example retrieves the perimeter of NewMeasurable measure.
            |    Dim APerimeter As double
            |    APerimeter = NewMeasurable.Perimeter


        :return: float
        :rtype: float
        """

        return self.measurable.Perimeter

    @property
    def radius(self) -> float:
        """
        ..note ::
            CAA V5 Visual Basic help

            Property Radius( ) As double (Read Only)

            | Returns the radius of an arc, cylinder or sphere.
            | Example:
            | This example retrieves the Radius of NewMeasurable measure.
            |   Dim ARadius As double
            |   ARadius = NewMeasurable.Radius


        :return: float
        :rtype: float
        """

        return self.measurable.Radius

    @property
    def volume(self) -> float:
        """
        ..note::
            CAA V5 Visual Basic help
            Property Volume( ) As double (Read Only)

            | Returns the volume.
            | Example:
            | This example retrieves the volume of NewMeasurable measure. The volume unit given by oVolume is m^3
            |   Dim AVolume As double
            |   AVolume = NewMeasurable.Volume


        :return: float
        :rtype: float
        """

        return self.measurable.Volume

    def get_angle_between(self, i_measured_item: Reference) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

        :param Reference i_measured_item:

            | Compute the angle between the CATIAMeasurable and another.
            | Example:
            | This example retrieves the angle between the reference1 and reference2.

            | Dim reference1 As Reference
            | Set reference1 = part1.CreateReferenceFromObject(object1)

            | Dim reference2 As Reference
            | Set reference2 = part1.CreateReferenceFromObject(object1)

            | Dim TheSPAWorkbench As Workbench
            | Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )

            | Dim TheMeasurable As Measurable
            | Set TheMeasurable = TheSPAWorkbench.GetMeasurable(reference1)

            | Dim MinimumDistance As double
            | MinimumDistance = TheMeasurable.GetAngleBetween(reference2)


        :return: float
        :rtype: float
        """

        return self.measurable.GetAngleBetween(i_measured_item.com_object)

    def get_axis(self):
        """
        ..note::
            CAA V5 Visual Basic help

            Sub GetAxis( CATSafeArrayVariant  oAxisVector)

            | Retrieves the axis vector of the cylinder or a cone.
            | Parameters:
            | oVector
            | The axis vector of the cylinder or a cone with respect to the product coordinate system:
            | oAxisVector(0) is the X direction
            | oAxisVector(1) is the Y direction
            | oAxisVector(2) is the Z direction
            | Example:
            | This example retrieves the axis vector of the cylinder or a cone of NewMeasurable measure.
            |    Dim AxisVector (2)
            |    NewMeasurable.GetAxis AxisVector

        :return: tuple(float, float, float)
        """
        vba_function_name = 'get_axis'
        vba_function = 'GetAxis'
        vba_code = f'''   
        Public Function {vba_function_name}(measurable)
            Dim AxisVector (2)
            measurable.{vba_function} AxisVector
            {vba_function_name} = AxisVector
        End Function
        '''

        system_service = self.application.system_service
        result = system_service.evaluate(vba_code, 0, vba_function_name,
                                         [self.measurable])

        return result

    def get_axis_system(self):
        """
        ..note ::
            CAA V5 Visual Basic help

            Sub GetAxisSystem( CATSafeArrayVariant  oComponents)

            | Retrieves the information of the axis system.
            | Parameters:
            | oCoordinates
            | The information of the axis system with respect to the product coordinate system:
            | oComponents(0) is the X coordinate of the origin of the axis system
            | oComponents(1) is the Y coordinate of the origin of the axis system
            | oComponents(2) is the Z coordinate of the origin of the axis system
            | oComponents(3) is the X coordinate of the first direction of the axis system
            | oComponents(4) is the Y coordinate of the first direction of the axis system
            | oComponents(5) is the Z coordinate of the first direction of the axis system
            | oComponents(6) is the X coordinate of the second direction of the axis system
            | oComponents(7) is the Y coordinate of the second direction of the axis system
            | oComponents(8) is the Z coordinate of the second direction of the axis system
            | oComponents(9) is the X coordinate of the third direction of the axis system
            | oComponents(10) is the Y coordinate of the third direction of the axis system
            | oComponents(11) is the Z coordinate of the third direction of the axis system
            | Example:
            | This example retrieves information of the axis system of NewMeasurable measure.
            |    Dim Components (11)
            |    NewMeasurable.GetAxisSystem Components

        :return: tuple(float, float, float, float, float, float, float, float, float, float, float, float)
        """

        vba_function_name = 'get_axis_system'
        vba_function = 'GetAxisSystem'
        vba_code = f'''        
            Public Function {vba_function_name}(measurable)
                Dim Components (11)
                measurable.{vba_function} Components
                {vba_function_name} = Components
            End Function
            '''
        system_service = self.application.system_service
        result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

        return result

    def get_cog(self):
        """
        .. note::
            FROM CAA V5 Visual Basic help

            Sub GetCOG( CATSafeArrayVariant  oCoordinates)

            | Retrieves the position of the center of gravity of a surface and volume .
            | Parameters:
            | oCoordinates
            | The position of the center of gravity with respect to the product coordinate system:
            | oCoordinates(0) is the X coordinate
            | oCoordinates(1) is the Y coordinate
            | oCoordinates(2) is the Z coordinate
            | Example:
            | This example retrieves the position of the center of gravity of NewMeasurable measure.
            |    Dim Coordinates (2)
            |    NewMeasurable.GetCOG Coordinates

        :return: tuple(float, float, float)
        """

        vba_function_name = 'create_cog'
        vba_function = 'GetCOG'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable)
            Dim coord(2)
            measurable.{vba_function} coord
            {vba_function_name} = coord
        End Function
        '''

        system_service = self.application.system_service
        result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

        return result

    def get_center(self):
        """
        ..note::
            CAA V5 Visual Basic help
            Sub GetCenter( CATSafeArrayVariant  oCoordinates)

            | Retrieves the position of the center of a circle or sphere.
            | Parameters:
            | oCoordinates
            | The position of the center with respect to the product coordinate system:
            | oCoordinates(0) is the X coordinate
            | oCoordinates(1) is the Y coordinate
            | oCoordinates(2) is the Z coordinate
            | Example:
            | This example retrieves the position of the center of NewMeasurable measure.
            |    Dim Coordinates (2)
            |    NewMeasurable.GetCenter Coordinates << fixed typo in help


        :return: tuple(float, float, float)
        """

        vba_function_name = 'get_center'
        vba_function = 'GetCenter'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable)
            Dim Coordinates (2)
            measurable.{vba_function} Coordinates
            {vba_function_name} = Coordinates
        End Function
        '''

        system_service = self.application.system_service
        result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

        return result

    def get_direction(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Sub GetDirection( CATSafeArrayVariant  oDirection)

            | Retrieves the direction of the line.
            | Parameters:
            | oDirection
            | The direction of the line with respect to the product coordinate system:
            | oDirection(0) is the X direction
            | oDirection(1) is the Y direction
            | oDirection(2) is the Z direction
            | Example:
            | This example retrieves the direction of the line of NewMeasurable measure.
            |    Dim Direction (2)
            |    NewMeasurable.GetDirection Direction


        :return: tuple(float, float, float)
        """

        vba_function_name = 'get_direction'
        vba_function = 'GetDirection'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable)
            Dim direction (2) 
            measurable.{vba_function} direction
            {vba_function_name} = direction
        End Function
        '''

        system_service = self.application.system_service
        result = system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

        return result

    def get_minimum_distance(self, i_measured_item):
        # noinspection SpellCheckingInspection
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Func GetMinimumDistance( Reference  iMeasuredItem) As double

            | Compute the minimum distance between the CATIAMeasurable and another.
            | Bodies (openbody, hybridbody..) cannot be measured between.
            | Parameters:
            | oCoordinates
            | The information of the axis system with respect to the product coordinate system:
            | oComponents(0) is the X coordinate of the origin of the axis system
            | oComponents(1) is the Y coordinate of the origin of the axis system
            | oComponents(2) is the Z coordinate of the origin of the axis system
            | oComponents(3) is the X coordinate of the first direction of the axis system
            | oComponents(4) is the Y coordinate of the first direction of the axis system
            | oComponents(5) is the Z coordinate of the first direction of the axis system
            | Example:
            |   This example retrieves the distance between the reference1 and reference2.
            |   Dim reference1 As Reference
            |   Set reference1 = part1.CreateReferenceFromObject(object1)
            |   Dim reference2 As Reference
            |   Set reference2 = part1.CreateReferenceFromObject(object1)
            |   Dim TheSPAWorkbench As Workbench
            |   Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )
            |   Dim TheMeasurable As Measurable
            |   Set TheMeasurable = TheSPAWorkbench.GetMeasurable(reference1)
            |   Dim MinimumDistance As double
            |   MinimumDistance = TheMeasurable.GetMinimumDistance(reference2)


        :return: float
        """

        return self.measurable.GetMinimumDistance(i_measured_item.com_object)

    def get_minimum_distance_points(self, i_measured_item):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Sub GetMinimumDistancePoints( Reference  iMeasuredItem, CATSafeArrayVariant  oCoordinates)

            | Compute the points corresponding to the minimum distance between the two references.
            | Example:
            | This example retrieves the points corresponding to the distance between the reference1 and reference2.
            |   Dim reference1 As Reference
            |   Set reference1 = part1.CreateReferenceFromObject(object1)
            |   Dim reference2 As Reference
            |   Set reference2 = part1.CreateReferenceFromObject(object1)
            |   Dim TheSPAWorkbench As Workbench
            |   Set TheSPAWorkbench = CATIA.ActiveDocument.GetWorkbench ( "SPAWorkbench" )
            |   Dim TheMeasurable As Measurable
            |   Set TheMeasurable = TheSPAWorkbench.GetMeasurable(reference1)
            |   Dim Coordinates (8)
            |   TheMeasurable.GetMinimumDistancePoints reference2, Coordinates

        :param i_measured_item:
        :return: tuple(float, float, float, float, float, float, float, float, float)
        """

        vba_function_name = 'get_minimum_distance_points'
        vba_function = 'GetMinimumDistancePoints'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable, i_measured_item)
            Dim Coordinates (8) 
            measurable.{vba_function} i_measured_item, Coordinates
            {vba_function_name} = Coordinates
        End Function
        '''

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable, i_measured_item.com_object])

    def get_plane(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Sub GetPlane( CATSafeArrayVariant  oComponents)

            | Retrieves informations of the plane.
            | Parameters:
            | oComponents
            | The informations of the plane with respect to the product coordinate system:
            | oComponents(0) is the X coordinate of the origin
            | oComponents(1) is the Y coordinate of the origin
            | oComponents(2) is the Z coordinate of the origin
            | oComponents(3) is the X coordinate of the first direction of the plane
            | oComponents(4) is the Y coordinate of the first direction of the plane
            | oComponents(5) is the Z coordinate of the first direction of the plane
            | oComponents(6) is the X coordinate of the second direction of the plane
            | oComponents(7) is the Y coordinate of the second direction of the plane
            | oComponents(8) is the Z coordinate of the second direction of the plane
            | Example:
            | This example retrieves informations of the plane of NewMeasurable measure.
            |    Dim Components (8)
            |    NewMeasurable.GetPlane Components

        :return: tuple(float, float, float, float, float, float, float, float)
        """

        vba_function_name = 'get_plane'
        vba_function = 'GetPlane'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable)
            Dim Components (8)
            measurable.{vba_function} Components
            {vba_function_name} = Components
        End Function
        '''

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

    def get_point(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help
            Sub GetPoint( CATSafeArrayVariant  oCoordinates)

            | Retrieves the position of the point.
            | Parameters:
            | oCoordinates
            | The coordinate of the point with respect to the product coordinate system:
            | oCoordinates(0) is the X coordinate
            | oCoordinates(1) is the Y coordinate
            | oCoordinates(2) is the Z coordinate
            | Example:
            | This example retrieves the coordinate of the point of NewMeasurable measure.
            |    Dim Coordinates (2)
            |    NewMeasurable.GetPoint Coordinates

        :return: tuple(float, float, float)
        """

        vba_function_name = 'get_point'
        vba_function = 'GetPoint'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable)
            Dim Coordinates (2)
            measurable.{vba_function} Coordinates
            {vba_function_name} = Coordinates
        End Function
        '''

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

    def get_points_on_axis(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Sub GetPointsOnAxis( CATSafeArrayVariant  oCoordinates)

            | Retrieves the the characteristic points of the axis with respect of the size of the revolution object.
            | Parameters:
            | oCoordinates
            | The information of the characteristic points with respect to the product coordinate system:
            | oCoordinates(0) is the X coordinate of the centerpoint of the axis
            | oCoordinates(1) is the Y coordinate of the centerpoint of the axis
            | oCoordinates(2) is the Z coordinate of the centerpoint of the axis
            | oCoordinates(3) is the X coordinate of the startpoint of the axis
            | oCoordinates(4) is the Y coordinate of the startpoint of the axis
            | oCoordinates(5) is the Z coordinate of the startpoint of the axis
            | oCoordinates(6) is the X coordinate of the endpoint of the axis
            | oCoordinates(7) is the Y coordinate of the endpoint of the axis
            | oCoordinates(8) is the Z coordinate of the endpoint of the axis
            | Example:
            | This example retrieves the characteristic points of the axis of NewMeasurable measure.
            |    Dim Coordinates (8)
            |    NewMeasurable.GetPointsOnAxis Coordinates


        :return: tuple(float, float, float, float, float, float, float, float)
        """

        vba_function_name = 'get_points_on_axis'
        vba_function = 'GetPointsOnAxis'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable)
            Dim Coordinates (8)
            measurable.{vba_function} Coordinates
            {vba_function_name} = Coordinates
        End Function
        '''

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

    def get_points_on_curve(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic help

            Sub GetPointsOnCurve( CATSafeArrayVariant  oCoordinates)

            | Retrieves the characteristic points of the curve : the start point, the middle point and the end point.
            | Parameters:
            | oCoordinates
            | The information of the characteristic points of the curve with respect to the product coordinate system:
            | oCoordinates(0) is the X coordinate of the startpoint of the curve
            | oCoordinates(1) is the Y coordinate of the startpoint of the curve
            | oCoordinates(2) is the Z coordinate of the startpoint of the curve
            | oCoordinates(3) is the X coordinate of the midpoint of the curve
            | oCoordinates(4) is the Y coordinate of the midpoint of the curve
            | oCoordinates(5) is the Z coordinate of the midpoint of the curve
            | oCoordinates(6) is the X coordinate of the endpoint of the curve
            | oCoordinates(7) is the Y coordinate of the endpoint of the curve
            | oCoordinates(8) is the Z coordinate of the endpoint of the curve
            | Example:
            | This example retrieves the characteristic points of the curve of NewMeasurable measure.
            |    Dim Coordinates (8)
            |    NewMeasurable.GetPointsOnCurve Coordinates

        :return: tuple(float, float, float, float, float, float, float, float)
        """

        vba_function_name = 'get_points_on_curve'
        vba_function = 'GetPointsOnCurve'
        vba_code = f'''        
        Public Function {vba_function_name}(measurable)
            Dim Coordinates (8)
            measurable.{vba_function} Coordinates
            {vba_function_name} = Coordinates
        End Function
        '''

        system_service = self.application.system_service
        return system_service.evaluate(vba_code, 0, vba_function_name, [self.measurable])

    def __repr__(self):
        return f'CATIAMeasurable({self.name})'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class Printer(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Printer
                | 
                | Represents a printer handled by the printing subsystem.
                | This object is read only and gives access to some properties of the
                | printer.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.printer = com_object

    @property
    def device_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DeviceName() As CATBSTR (Read Only)
                | 
                |     Returns the printer device name.
                | 
                |     Example:
                |         This example displays the device name of the myPrinter
                |         printer.
                | 
                |          MsgBox myPrinter.DeviceName

        :return: str
        :rtype: str
        """

        return self.printer.DeviceName

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As CatPaperOrientation (Read Only)
                | 
                |     Returns or sets the default paper orientation.
                | 
                |     Example:
                |         This example retrieves in DefaultPaperOrientation the default paper
                |         orientation of the myPrinter printer.
                | 
                |          Dim DefaultPaperOrientation As CatPaperOrientation
                |          DefaultPaperOrientation = myPrinter.Orientation

        :return: int
        :rtype: int
        """

        return self.printer.Orientation

    @property
    def paper_height(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PaperHeight() As float (Read Only)
                | 
                |     Returns the default paper height.
                | 
                |     Example:
                |         This example retrieves in Height the default paper height of the
                |         myPrinter printer.
                | 
                |          Dim Height
                |          Height = myPrinter.PaperHeight

        :return: float
        :rtype: float
        """

        return self.printer.PaperHeight

    @property
    def paper_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PaperSize() As CatPaperSize (Read Only)
                | 
                |     Returns the default paper size.
                | 
                |     Example:
                |         This example retrieves in DefaultPaperSize the default paper size of
                |         the myPrinter printer.
                | 
                |          Dim DefaultPaperSize As CatPaperSize
                |          DefaultPaperSize = myPrinter.PaperSize

        :return: int
        :rtype: int
        """

        return self.printer.PaperSize

    @property
    def paper_width(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PaperWidth() As float (Read Only)
                | 
                |     Returns the default paper width.
                | 
                |     Example:
                |         This example retrieves in Witdh the default paper width of the
                |         myPrinter printer.
                | 
                |          Dim Width As float
                |          Width = myPrinter.PaperWidth

        :return: float
        :rtype: float
        """

        return self.printer.PaperWidth

    def __repr__(self):
        return f'Printer(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.part_interfaces.dress_up_shape import DressUpShape


class RemoveFace(DressUpShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             RemoveFace
                | 
                | Represents the Remove Face operation.
                | It removes a face or a set of faces.

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.remove_face = com_object

    @property
    def keep_face(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property KeepFace(Reference iKeepFace) (Write Only)
                | 
                |     Adds a new face to be Kept.
                | 
                |     Parameters:
                | 
                |         iKeepFace
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face.

        """

        return self.remove_face.KeepFace

    @keep_face.setter
    def keep_face(self, reference_face: Reference):
        """
        :param Reference reference_face:
        """

        self.remove_face.KeepFace = reference_face.com_object

    @property
    def keep_faces(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property KeepFaces() As References (Read Only)
                | 
                |     Get the specified faces to be kept.

        :return: References
        :rtype: References
        """

        return References(self.remove_face.KeepFaces)

    @property
    def propagation(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Propagation() As References (Read Only)
                | 
                |     Get the faces that will be removed.

        :return: References
        :rtype: References
        """

        return References(self.remove_face.Propagation)

    @property
    def remove_face(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RemoveFace(Reference iRemoveFace) (Write Only)
                | 
                |     Adds a new face to be removed.
                | 
                |     Parameters:
                | 
                |         iRemoveFace
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face.

        """

        return self.remove_face.RemoveFace

    @remove_face.setter
    def remove_face(self, reference_face: Reference):
        """
        :param Reference reference_face:
        """

        self.remove_face.RemoveFace = reference_face.com_object

    @property
    def remove_faces(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RemoveFaces() As References (Read Only)
                | 
                |     Get the specified faces to be removed.

        :return: References
        :rtype: References
        """

        return References(self.remove_face.RemoveFaces)

    def remove_keep_face(self, i_keep_face: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub remove_KeepFace(Reference iKeepFace)
                | 
                |     Removes a face to be Kept.
                | 
                |     Parameters:
                | 
                |         iKeepFace
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face.

        :param Reference i_keep_face:
        :return: None
        :rtype: None
        """
        return self.remove_face.remove_KeepFace(i_keep_face.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_keep_face'
        # # vba_code = """
        # # Public Function remove_keep_face(remove_face)
        # #     Dim iKeepFace (2)
        # #     remove_face.remove_KeepFace iKeepFace
        # #     remove_keep_face = iKeepFace
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def remove_remove_face(self, i_remove_face: Reference) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub remove_RemoveFace(Reference iRemoveFace)
                | 
                |     Removes a face to be removed.
                | 
                |     Parameters:
                | 
                |         iRemoveFace
                |             The new face to process
                |             The following 
                | 
                |         Boundary object is supported: Face.

        :param Reference i_remove_face:
        :return: None
        :rtype: None
        """
        return self.remove_face.remove_RemoveFace(i_remove_face.com_object)
        # # # # Autogenerated comment:
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_remove_face'
        # # vba_code = """
        # # Public Function remove_remove_face(remove_face)
        # #     Dim iRemoveFace (2)
        # #     remove_face.remove_RemoveFace iRemoveFace
        # #     remove_remove_face = iRemoveFace
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RemoveFace(name="{self.name}")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.drafting_interfaces.drawing_text_properties import DrawingTextProperties
from pycatia.system_interfaces.cat_base_dispatch import CATBaseDispatch


class DrawingTextRange(CATBaseDispatch):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 DrawingTextRange
                | 
                | Represents a drawing text range, or contiguous area, in a drawing
                | text.
                | 
                | A range is a contiguous area in a drawing text defined by the position of a
                | starting and ending character, or by the position of a starting character and a
                | length expressed in number of characters.
    
    """

    def __init__(self, com_object):
        super().__init__()
        self.drawing_text_range = com_object

    @property
    def length(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Length() As long (Read Only)
                | 
                |     Returns the number of characters of the drawing text
                |     range.
                | 
                |     Example:
                |         This example retrieves in NbChar the number of characters of the
                |         MyTextRange drawing text range.
                | 
                |          NbChar = MyTextRange.Length

        :return: int
        :rtype: int
        """

        return self.drawing_text_range.Length

    @property
    def start(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Start() As long (Read Only)
                | 
                |     Returns the starting character position of the drawing text
                |     range.
                | 
                |     Example:
                |         This example retrieves in StartCharPosthe starting character position
                |         of the MyTextRange drawing text range.
                | 
                |          StartCharPos = MyTextRange.Start

        :return: int
        :rtype: int
        """

        return self.drawing_text_range.Start

    @property
    def text(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property Text() As CATBSTR
                | 
                |     Returns or sets the character string making up the drawing text
                |     range.
                | 
                |     Example:
                |         This example sets in text the character string that makes up the
                |         MyTextRange drawing text range.
                | 
                |          MyTextRange.Text = text
                |          Set MyTextProperties = MyTextRange.TextProperties
                |          MyTextProperties.Update
                |          
                | 
                |     See also:
                |         DrawingTextProperties.Update

        :return: str
        :rtype: str
        """

        return self.drawing_text_range.Text

    @text.setter
    def text(self, value: str):
        """
        :param str value:
        """

        self.drawing_text_range.Text = value

    @property
    def text_properties(self) -> DrawingTextProperties:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property TextProperties() As DrawingTextProperties (Read
                | Only)
                | 
                |     Deprecated:
                |         V5R18 use DrawingWelding.TextProperties This method has not to be used
                |         to manage the text range properties. Text properties is only applied on the
                |         whole text, not on a sub text identified by a text range. Returns the drawing
                |         text range properties.
                | 
                |         Example:
                |             This example returns in Prop the text properties of the MyTextRange
                |             drawing text range.
                | 
                |              Dim Prop As CATIADrawingTextProperties
                |              Set Prop = MyTextRange.TextProperties(String)

        :return: DrawingTextProperties
        :rtype: DrawingTextProperties
        """

        return DrawingTextProperties(self.drawing_text_range.TextProperties)

    def get_text_range(self, i_start: int, i_end: int) -> 'DrawingTextRange':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetTextRange(long iStart,
                | long iEnd) As DrawingTextRange
                | 
                |     Returns a drawing text range within another drawing text range. The text
                |     range is retrieved using its starting and ending character
                |     positions.
                | 
                |     Parameters:
                | 
                |         iStart
                |             The position of the drawing text range starting character
                |             
                |         iEnd
                |             The position of the drawing text range ending character
                |             
                | 
                |     Example:
                |         This example retrieves in extractedTextRange the drawing text range
                |         that begins at the eighth character and end at the fifteenth character of the
                |         MyTextRange drawing text range.
                | 
                |          Dim extractedTextRange As DrawingTextRange
                |          start = 8
                |          end = 15
                |          extractedTextRange = MyTextRange.GetTextRange(start, end)

        :param int i_start:
        :param int i_end:
        :return: DrawingTextRange
        :rtype: DrawingTextRange
        """
        return DrawingTextRange(self.drawing_text_range.GetTextRange(i_start, i_end))

    def insert_after(self, i_string: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub InsertAfter(CATBSTR iString)
                | 
                |     Inserts a character string at the end of the drawing text
                |     range.
                | 
                |     Parameters:
                | 
                |         iString
                |             The character string to be added 
                | 
                |     Example:
                |         This example inserts the String character string at the end of the
                |         MyTextRange drawing text range.
                | 
                |          String = "String to insert after"
                |          MyTextRange.InsertAfter(String)
                |          Set MyTextProperties = MyTextRange.TextProperties
                |          MyTextProperties.Update
                |          
                | 
                | See also:
                |     DrawingTextProperties.Update

        :param str i_string:
        :return: None
        :rtype: None
        """
        return self.drawing_text_range.InsertAfter(i_string)

    def insert_before(self, i_string: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub InsertBefore(CATBSTR iString)
                | 
                |     Inserts a character string at the beginning of the drawing text
                |     range.
                | 
                |     Parameters:
                | 
                |         iString
                |             The character string to be added 
                | 
                |     Example:
                |         This example inserts the String character string at the beginning of
                |         the MyTextRange drawing text range.
                | 
                |          String = "String to insert before"
                |          MyTextRange.InsertBefore(String)
                |          Set MyTextProperties = MyTextRange.TextProperties
                |          MyTextProperties.Update
                |          
                | 
                | See also:
                |     DrawingTextProperties.Update
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :param str i_string:
        :return: None
        """
        return self.drawing_text_range.InsertBefore(i_string)

    def __repr__(self):
        return f'DrawingTextRange()'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class MacrosSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         MacrosSettingAtt
                | 
                | Setting controller for the Macros tab page.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.macros_setting_att = com_object

    def get_default_macro_libraries(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDefaultMacroLibraries() As CATSafeArrayVariant
                | 
                |     Returns the list of default macro libraries.

        :return: tuple
        :rtype: tuple
        """
        return self.macros_setting_att.GetDefaultMacroLibraries()

    def get_default_macro_libraries_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetDefaultMacroLibrariesInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the default macro libraries
                |     setting.
                |     Role:Retrieves the state of the parameter default macro libraries setting
                |     in the current environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.macros_setting_att.GetDefaultMacroLibrariesInfo(admin_level, o_locked)

    def get_external_references(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExternalReferences() As CATSafeArrayVariant
                | 
                |     Returns the list of external references.

        :return: tuple
        :rtype: tuple
        """
        return self.macros_setting_att.GetExternalReferences()

    def get_external_references_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetExternalReferencesInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the external references
                |     setting.
                |     Role:Retrieves the state of the parameter external references setting in
                |     the current environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.macros_setting_att.GetExternalReferencesInfo(admin_level, o_locked)

    def get_language_editor(self, i_language: int) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLanguageEditor(CATScriptLanguage iLanguage) As
                | CATBSTR
                | 
                |     Returns the editor path for the specified language.

        :param int i_language:
        :return: str
        :rtype: str
        """
        return self.macros_setting_att.GetLanguageEditor(i_language)

    def get_language_editor_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func GetLanguageEditorInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves environment informations for the language editors
                |     setting.
                |     Role:Retrieves the state of the parameter language editors setting in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value.

        :param str admin_level:
        :param str o_locked:
        :return: bool
        :rtype: bool
        """
        return self.macros_setting_att.GetLanguageEditorInfo(admin_level, o_locked)

    def set_default_macro_libraries(self, i_libraries: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDefaultMacroLibraries(CATSafeArrayVariant
                | iLibraries)
                | 
                |     Sets the list of default macro libraries.

        :param tuple i_libraries:
        :return: None
        :rtype: None
        """
        return self.macros_setting_att.SetDefaultMacroLibraries(i_libraries)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_macro_libraries'
        # # vba_code = """
        # # Public Function set_default_macro_libraries(macros_setting_att)
        # #     Dim iLibraries (2)
        # #     macros_setting_att.SetDefaultMacroLibraries iLibraries
        # #     set_default_macro_libraries = iLibraries
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_macro_libraries_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetDefaultMacroLibrariesLock(boolean iLocked)
                | 
                |     Locks or unlocks the default macro libraries setting.
                |     Role:Locks or unlocks the default macro libraries setting if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             True : to lock the parameter.
                |             False: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.macros_setting_att.SetDefaultMacroLibrariesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_macro_libraries_lock'
        # # vba_code = """
        # # Public Function set_default_macro_libraries_lock(macros_setting_att)
        # #     Dim iLocked (2)
        # #     macros_setting_att.SetDefaultMacroLibrariesLock iLocked
        # #     set_default_macro_libraries_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_external_references(self, i_references: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExternalReferences(CATSafeArrayVariant iReferences)
                | 
                |     Sets the list of external references.

        :param tuple i_references:
        :return: None
        :rtype: None
        """
        return self.macros_setting_att.SetExternalReferences(i_references)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_external_references'
        # # vba_code = """
        # # Public Function set_external_references(macros_setting_att)
        # #     Dim iReferences (2)
        # #     macros_setting_att.SetExternalReferences iReferences
        # #     set_external_references = iReferences
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_external_references_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetExternalReferencesLock(boolean iLocked)
                | 
                |     Locks or unlocks the external references setting.
                |     Role:Locks or unlocks the external references setting if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             True : to lock the parameter.
                |             False: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.macros_setting_att.SetExternalReferencesLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_external_references_lock'
        # # vba_code = """
        # # Public Function set_external_references_lock(macros_setting_att)
        # #     Dim iLocked (2)
        # #     macros_setting_att.SetExternalReferencesLock iLocked
        # #     set_external_references_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_language_editor(self, i_language: int, i_editor_path: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLanguageEditor(CATScriptLanguage iLanguage,
                | CATBSTR iEditorPath)
                | 
                |     Sets the editor path for the specified language.

        :param int i_language:
        :param str i_editor_path:
        :return: None
        :rtype: None
        """
        return self.macros_setting_att.SetLanguageEditor(i_language, i_editor_path)

    def set_language_editor_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetLanguageEditorLock(boolean iLocked)
                | 
                |     Locks or unlocks the language editors setting.
                |     Role:Locks or unlocks the language editors setting if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             True : to lock the parameter.
                |             False: to unlock the parameter.

        :param bool i_locked:
        :return: None
        :rtype: None
        """
        return self.macros_setting_att.SetLanguageEditorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_language_editor_lock'
        # # vba_code = """
        # # Public Function set_language_editor_lock(macros_setting_att)
        # #     Dim iLocked (2)
        # #     macros_setting_att.SetLanguageEditorLock iLocked
        # #     set_language_editor_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MacrosSettingAtt(name="{ self.name }")'



#! usr/bin/python3.6
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.fillet import Fillet


class FaceFillet(Fillet):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             PartInterfaces.Fillet
                |                                 FaceFillet
                | 
                | Represents the face fillet shape.
                | A face fillet shape is built between two faces with a fillet
                | radius.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.face_fillet = com_object

    @property
    def first_face(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FirstFace() As Reference
                | 
                |     Returns or sets the first limiting face.
                |     To set the property, you can use the following Boundary object:
                |     Face.
                | 
                |     Example:
                |         The following example returns in face1 the first limiting face of the
                |         face fillet firstFaceFillet, and then sets it to
                |         NewFace1:
                | 
                |          Set face1 = firstFaceFillet.FirstFace
                |          firstFaceFillet.FirstFace = NewFace1

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.face_fillet.FirstFace)

    @first_face.setter
    def first_face(self, value: Reference):
        """
        :param Reference value:
        """

        self.face_fillet.FirstFace = value

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     Returns the face fillet radius.
                | 
                |     Example:
                |         The following example returns in radius the fillet radius of the face
                |         fillet firstFaceFillet:
                | 
                |          Set radius = firstFaceFillet.Radius

        :return: Length
        :rtype: Length
        """

        return Length(self.face_fillet.Radius)

    @property
    def second_face(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SecondFace() As Reference
                | 
                |     Returns or sets the second limiting face.
                |     To set the property, you can use the following Boundary object:
                |     Face.
                | 
                |     Example:
                |         The following example returns in face2 the second limiting face of the
                |         face fillet firstFaceFillet, and then sets it to
                |         NewFace2:
                | 
                |          Set face2 = firstFaceFillet.SecondFace
                |          firstFaceFillet.SecondFace = NewFace2

        :return: Reference
        :rtype: Reference
        """

        return Reference(self.face_fillet.SecondFace)

    @second_face.setter
    def second_face(self, value: Reference):
        """
        :param Reference value:
        """

        self.face_fillet.SecondFace = value

    def __repr__(self):
        return f'FaceFillet(name="{ self.name }")'
